// Import the required packages
const otplib = require('otplib');
const clipboardy = require('clipboardy');

// Variable to store the last generated token
let lastToken = '';

// Function to check and display the 2FA code if it changes
async function checkForNewCode() {
    try {
        // Read the secret key from the clipboard
        const secret = await clipboardy.read();

        // Generate the TOTP code using the secret from the clipboard
        const currentToken = otplib.authenticator.generate(secret);

        // If the current token is different from the last token, log it
        if (currentToken !== lastToken) {
            console.log(`New 2FA code: ${currentToken}`);
            lastToken = currentToken;
        }
    } catch (error) {
        console.error("Failed to read from clipboard or generate TOTP:", error);
    }
}

// Run the check every second (1000 ms) to monitor changes in the TOTP code
setInterval(checkForNewCode, 1000);
